<?php

declare(strict_types=1);

namespace Drupal\entity_type_access_conditions_test\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a test condition for the views access conditions module.
 *
 * @Condition(
 *   id = "test_condition",
 *   label = @Translation("Test condition"),
 *   context_definitions = {}
 * )
 */
class TestCondition extends ConditionPluginBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'condition_met' => TRUE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['condition_met'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Condition is met'),
      '#default_value' => $this->configuration['condition_met'],
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['condition_met'] = $form_state->getValue('condition_met');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    return $this->configuration['condition_met'];
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->t('Test condition is @state', [
      '@state' => $this->configuration['condition_met'] ? $this->t('met') : $this->t('not met'),
    ]);
  }

}
